@@ -12,19 +12,24 @@ from .types import *
 
 
 class MT5Error(Exception):
-    pass
+    def __init__(self, error_code: _const.ERROR_CODE, description: str):
+        super().__init__()
+        self.error_code = error_code
+        self.description = description
 
 
 def _context_manager_modified(f):
     @functools.wraps(f)
     def cmm_wrapped_func(*args, **kwargs):
         result = f(*args, **kwargs)
+        last_err = None
         if _state.debug_logging:
+            last_err = mt5_last_error()
             call_sig = f"{f.__name__}({_h.args_to_str(args, kwargs)})"
-            _state.logger(f"[{call_sig}][{mt5_last_error()}][{str(result)[:80]}]")
+            _state.logger(f"[{call_sig}][{last_err}]")
         # make sure we logger before we raise
-        if _state.raise_on_errors:  # no need to check last error if we got a result
-            error_code, description = mt5_last_error()
+        if _state.raise_on_errors and not result:  # no need to check last error if we got a result
+            error_code, description = last_err or mt5_last_error()
             if error_code != _const.ERROR_CODE.OK:
                 if error_code == _const.ERROR_CODE.INVALID_PARAMS:
                     description += str(args) + str(kwargs)
